![](https://github.com/TheShellLand/automon-core/raw/master/docs/images/sauruspark.gif)

# Automonisaur: Core Libraries

**[about](#about)** | **[integrations](#integrations)** | **[install](#install)** | **[build](#build)** | **[unittest in docker](#unittest-in-docker')** | 
**[unittest locally](#unittest-locally)** | **[codecov](https://codecov.io/gh/TheShellLand/automon-core)**

[![codecov](https://codecov.io/gh/TheShellLand/automon-core/branch/master/graph/badge.svg)](https://codecov.io/gh/TheShellLand/automon-core) [![CI](https://github.com/TheShellLand/automonisaur/workflows/CI/badge.svg?branch=master)](https://github.com/TheShellLand/automonisaur/actions)


#### about

This library adds some easier-to-use wrappers around common services used in cyber security and threat intelligence.

Provides easier clients and configuration options, as well as any additional helpers to get things up and running.

Github issues and feature requests welcomed.


###### integrations

- airport
- elasticsearch
- flask
- minio
- neo4j
- selenium
- slack
- snmp
- splunk
- swift
- vds


#### install library
```shell script
./install.sh
```

#### build docker
```shell script
./build.sh
```

#### unittest in docker
```shell script
./test.sh
```

#### unittest locally
```shell script
./unittests.sh
```
